import React from 'react';
import { optionsMap } from './ChoroplethLayer';

type Props = {
  layer: any;
  updatedLayer: any;
  graphInfo: any;
  deleteLayer: any;
};

export default function ChoroplethOptions({ layer, updatedLayer, graphInfo, deleteLayer }: Props) {
  const optionsType: any = optionsMap[layer.config.data.type as 'nodes' | 'edges'];

  return (
    <div>
      <div className="divider m-0"></div>

      <div>
        <h5>Graph Data</h5>
        <select
          className="select select-bordered w-full max-w-xs"
          value={layer.config.data.type}
          onChange={(e) =>
            updatedLayer(layer.id, {
              config: {
                ...layer.config,
                data: {
                  ...layer.config.data,
                  type: e.target.value,
                },
              },
            })
          }
        >
          <option disabled selected>
            Type
          </option>
          {Object.keys(optionsMap).map((key) => (
            <option key={key} value={key}>
              {key}
            </option>
          ))}
        </select>

        {layer.config.data.type && (
          <select
            className="select select-bordered w-full max-w-xs"
            value={layer.config.data.operation}
            onChange={(e) =>
              updatedLayer(layer.id, {
                config: {
                  ...layer.config,
                  data: {
                    ...layer.config.data,
                    operation: e.target.value,
                  },
                },
              })
            }
          >
            <option disabled selected>
              Operation
            </option>
            {optionsType &&
              Object.keys(optionsType.operations).map((key) => (
                <option key={key} value={key}>
                  {key}
                </option>
              ))}
          </select>
        )}

        {layer.config.data.operation && (
          <select
            className="select select-bordered w-full max-w-xs"
            value={layer.config.data.attribute}
            onChange={(e) =>
              updatedLayer(layer.id, {
                config: {
                  ...layer.config,
                  data: {
                    ...layer.config.data,
                    attribute: e.target.value,
                  },
                },
              })
            }
          >
            <option disabled selected>
              Attribute
            </option>
            {layer.config.data.operation &&
              Object.keys(optionsType.operations[layer.config.data.operation]).map((key) => (
                <option key={key} value={key}>
                  {key}
                </option>
              ))}
          </select>
        )}
      </div>

      <div className="divider m-0"></div>

      <div>
        <div className="form-control">
          <label className="label cursor-pointer">
            <span className="label-text">Edges on hover</span>
            <input
              type="checkbox"
              checked={layer.config.edgesOnHover}
              className="checkbox"
              onChange={(e) =>
                updatedLayer(layer.id, {
                  config: {
                    ...layer.config,
                    edgesOnHover: e.target.checked,
                  },
                })
              }
            />
          </label>
        </div>

        <div className="form-control">
          <label className="label cursor-pointer">
            <span className="label-text">Tilt on select</span>
            <input
              type="checkbox"
              checked={layer.config.pitchOnSelect}
              className="checkbox"
              onChange={(e) =>
                updatedLayer(layer.id, {
                  config: {
                    ...layer.config,
                    pitchOnSelect: e.target.checked,
                  },
                })
              }
            />
          </label>
        </div>
      </div>

      <div className="divider m-0"></div>

      <div>
        <button
          className="btn btn-primary w-full"
          onClick={() =>
            updatedLayer(layer.id, {
              visible: !layer.visible,
            })
          }
        >
          {layer.visible ? 'Hide layer' : 'Show layer'}
        </button>

        <button className="btn btn-outline btn-primary w-full mt-1" onClick={() => deleteLayer(layer.id)}>
          Delete layer
        </button>
      </div>
    </div>
  );
}
